@@ -1,6 +1,7 @@
 from typing import TYPE_CHECKING
 
 import pytz
+from django.contrib.auth import get_user_model
 from django.db import models, transaction
 from django.db.models import (
     BooleanField,
@@ -15,16 +16,16 @@ from django.db.models import (
     TextField,
 )
 from django.utils import formats
-from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _
+from guardian.shortcuts import assign_perm
 from polymorphic.models import PolymorphicModel
 
 from ephios import settings
 from ephios.extra.json import CustomJSONDecoder, CustomJSONEncoder
-from ephios.user_management.models import UserProfile
 
 if TYPE_CHECKING:
     from ephios.event_management.signup import AbstractParticipant
+    from ephios.user_management.models import UserProfile
 
 
 class ActiveManager(Manager):
@@ -41,11 +42,7 @@ class EventType(Model):
         verbose_name_plural = _("event types")
 
     def __str__(self):
-        return self.title
-
-
-class EventSeries(Model):
-    pass
+        return str(self.title)
 
 
 class Event(Model):
@@ -53,7 +50,6 @@ class Event(Model):
     description = TextField(_("description"), blank=True, null=True)
     location = CharField(_("location"), max_length=254)
     type = ForeignKey(EventType, on_delete=models.CASCADE, verbose_name=_("event type"))
-    series = ForeignKey(EventSeries, on_delete=models.CASCADE, blank=True, null=True)
     active = BooleanField(default=False)
     mail_updates = BooleanField(_("send updates via mail"), default=True)
 
@@ -74,7 +70,7 @@ class Event(Model):
             return last_shift.end_time
 
     def __str__(self):
-        return self.title
+        return str(self.title)
 
     def get_absolute_url(self):
         from django.urls import reverse
@@ -99,9 +95,16 @@ class AbstractParticipation(PolymorphicModel):
         CONFIRMED = 1, _("confirmed")
         USER_DECLINED = 2, _("declined by user")
         RESPONSIBLE_REJECTED = 3, _("rejected by responsible")
+        GETTING_DISPATCHED = 4, _("getting dispatched")
 
     shift = ForeignKey("Shift", on_delete=models.CASCADE, verbose_name=_("shift"))
-    state = IntegerField(_("state"), choices=States.choices, default=States.REQUESTED)
+    state = IntegerField(_("state"), choices=States.choices)
+    data = models.JSONField(default=dict)
+
+    @property
+    def hours_value(self):
+        td = self.shift.end_time - self.shift.start_time
+        return td.total_seconds() / (60 * 60)
 
     @property
     def participant(self) -> "AbstractParticipant":
@@ -129,8 +132,9 @@ class Shift(Model):
     class Meta:
         verbose_name = _("shift")
         verbose_name_plural = _("shifts")
+        ordering = ("meeting_time", "start_time", "id")
 
-    @cached_property
+    @property
     def signup_method(self):
         from ephios.event_management.signup import signup_method_from_slug
 
@@ -159,7 +163,20 @@ class Shift(Model):
 
 
 class LocalParticipation(AbstractParticipation):
-    user = ForeignKey(UserProfile, on_delete=models.CASCADE)
+    user: "UserProfile" = ForeignKey(get_user_model(), on_delete=models.CASCADE)
+
+    def save(self, *args, **kwargs):
+        super().save(*args, **kwargs)
+        if (
+            not self.user.has_perm("event_management.view_event", obj=self.shift.event)
+            and self.state != self.States.GETTING_DISPATCHED
+        ):
+            # If dispatched by a responsible, the user should be able to view
+            # the event, if not already permitted through its group.
+            # Currently, this permission does not get removed automatically.
+            assign_perm(
+                "event_management.view_event", user_or_group=self.user, obj=self.shift.event
+            )
 
     @property
     def participant(self):
